@@ -5,10 +5,10 @@ use warnings;
 
 use Data::Validate::Domain qw( is_domain );
 use Data::Validate::Email qw( is_email );
-use Data::Validate::IP qw( is_ipv4 );
+use Data::Validate::IP qw( is_ipv4 is_ipv6 );
 use Data::Validate::URI qw( is_uri );
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 # ABSTRACT: WWW::LogicBoxes Moose Type Library
 
 use MooseX::Types -declare => [qw(
@@ -26,8 +26,12 @@ use MooseX::Types -declare => [qw(
     DomainStatus
     EmailAddress
     InvoiceOption
+    IP
+    IPs
     IPv4
     IPv4s
+    IPv6
+    IPv6s
     Language
     NexusCategory
     NexusPurpose
@@ -139,6 +143,14 @@ subtype IPv4, as Str,
     message { "$_ is not a valid ipv4 IP Address" };
 subtype IPv4s, as ArrayRef[IPv4];
 
+subtype IPv6, as Str,
+    where { is_ipv6( $_ ) },
+    message { "$_ is not a valid ipv6 IP Address" };
+subtype IPv6s, as ArrayRef[IPv6];
+
+subtype IP, as IPv4 | IPv6;
+subtype IPs, as ArrayRef[IP];
+
 subtype Password, as Str,
     where {(
         $_ =~ m/([a-zA-Z0-9])+/                  # Alphanumeric
